@@ -162,8 +162,32 @@ Glib::ustring Field::get_title_or_name() const
 
 Glib::ustring Field::sql(const Gnome::Gda::Value& value) const
 {
-  Glib::ustring str;
+  if(value.is_null())
+  {
+    switch(get_glom_type())
+    {
+      case(TYPE_TEXT):
+      {
+        return "''"; //We want to ignore the concept of NULL strings, and deal only with empty strings.
+        break;
+      }
+      case(TYPE_DATE):
+      case(TYPE_TIME):
+      case(TYPE_NUMERIC):
+      {
+        return "NULL";
+        break;
+      }
+      default:
+      {
+        //Don't deal with these here.
+        break;
+      }
+    }
+  }
 
+  Glib::ustring str;
+   
   switch(get_glom_type())
   {
     case(TYPE_TEXT):
@@ -241,6 +265,11 @@ Glib::ustring Field::get_sql_type() const
       }
     }
 
+    if(strType == "unknowntype")
+    {
+      g_warning("Field::get_sql_type(): returning unknowntype for field name=%s , glom_type=%d, gda_type=%d", get_name().c_str(), get_glom_type(), m_field_info.get_gdatype());
+    }
+    
     return strType;
   }
 }
@@ -287,6 +316,11 @@ Gnome::Gda::ValueType Field::get_gda_type_for_glom_type(Field::glom_field_type g
   if(iterFind != m_map_glom_type_to_gda_type.end())
     ideal_gda_type = iterFind->second;
 
+  if(ideal_gda_type == Gnome::Gda::VALUE_TYPE_UNKNOWN)
+  {
+    g_warning("Field::get_gda_type_for_glom_type(): Returning VALUE_TYPE_UNKNOWN for glom_type=%d", glom_type);
+  }
+  
   return ideal_gda_type;
 }
 
