@@ -511,7 +511,7 @@ void Frame_Glom::update_table_in_document_from_database()
 
   //Get the fields information from the database:
   Base_DB::type_vecFields fieldsDatabase = Base_DB::get_fields_for_table_from_database(m_strTableName);
-
+  
   Document_Glom* pDoc = dynamic_cast<const Document_Glom*>(get_document());
   if(pDoc)
   {
@@ -565,8 +565,9 @@ void Frame_Glom::update_table_in_document_from_database()
         fieldsActual.push_back(field);
       }
       else
+      {
         document_must_to_be_updated = true; //Something changed.
-      
+      }
     }
           
     if(document_must_to_be_updated)
@@ -669,31 +670,77 @@ bool Frame_Glom::connection_request_password_and_attempt()
 
     if(response == Gtk::RESPONSE_OK)
     {
-      sharedptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings();
-      if(!sharedconnection)
+      try
       {
-        //Warn the user, and let him try again:
-        int response = m_pDialogConnectionFailed->run();
-        m_pDialogConnectionFailed->hide();
-
-        if(response != Gtk::RESPONSE_OK)
-          return false; //The user cancelled.
+        sharedptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings();
+        return true; //Succeeeded, because no exception was thrown.
       }
-      else
-        return true;
+      catch(const ExceptionConnection& ex)
+      {
+        g_warning("Frame_Glom::connection_request_password_and_attempt(): caught exception.");
+         
+        if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
+        {
+          //Warn the user, and let him try again:
+          int response = m_pDialogConnectionFailed->run();
+          m_pDialogConnectionFailed->hide();
+
+          if(response != Gtk::RESPONSE_OK)
+            return false; //The user cancelled.
+        }
+        else
+        {
+          g_warning("Frame_Glom::connection_request_password_and_attempt(): rethrowing exception.");
+
+          //The connection to the server is OK, but the specified database does not exist:
+          throw ex; //Pass it on for the caller to handle.
+          return false;
+        }
+      }
+      
+      //Try again.
     }
     else
       return false; //The user cancelled.
   }
 }
 
-bool Frame_Glom::create_database(const Glib::ustring& database_name)
+bool Frame_Glom::create_database(const Glib::ustring& database_name, bool request_password)
 {
-  //Ask for connection details:                   
-  if(connection_request_password_and_attempt()) //If it succeeded and the user did not cancel.
+  //Ask for connection details:
+  bool connection_possible = false;
+  try
   {
-    //This must now succeeed, because we've already tried it once:
-    sharedptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings();
+    if(request_password)
+      connection_possible = connection_request_password_and_attempt(); //If it succeeded and the user did not cancel.
+    else
+      connection_possible = true; //Assume that connection details are already coorect.
+  }
+  catch(const ExceptionConnection& ex)
+  {
+     g_warning("debug Frame_Glom::create_database() 1 exception caught");
+ 
+    //connection_possible stays false.
+  }
+
+  if(connection_possible)
+  {
+    //This must now succeed, because we've already tried it once:
+    sharedptr<SharedConnection> sharedconnection;
+    try
+    {
+      if(request_password)
+        sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings();
+      else
+        sharedconnection = ConnectionPool::get_instance()->connect();
+    }
+    catch(const ExceptionConnection& ex)
+    {
+      g_warning("debug Frame_Glom::create_database() Connection failed.");
+ 
+      return false;
+    }
+      
     if(sharedconnection)
     {
       Bakery::BusyCursor(*get_app_window());
@@ -703,7 +750,10 @@ bool Frame_Glom::create_database(const Glib::ustring& database_name)
       {
         bool result = connection->create_database(database_name);
         if(result)
+        {
+          g_warning("Frame_Glom::create_database(): Succeeded: database_name=%s", database_name.c_str());
           return true; // It succeeded.
+        }
         else
         {
           //Tell the user:
